C....*...1.........2.........3.........4.........5.........6.........7.*.......8
C     DGMCPY    3/10/72
C
C     PURPOSE
C     COPY THE MATRIX A INTO R.
C
C     USAGE
C     CALL DGMCPY(A,R,N,M)
C
C     ARGUMENTS
C     A - INPUT N BY M MATRIX STORED COLUMNWISE (STORAGE MODE 0).
C         ELEMENTS OF A ARE REAL*8.
C     R - RESULTANT COPY OF A STORED COLUMNWISE (STORAGE MODE 0)
C         ELEMENTS OF R ARE REAL*8.
C     N - NUMBER OF ROWS IN A AND R.
C     M - NUMBER OF COLUMNS IN A AND R.
C
      SUBROUTINE DGMCPY(A,R,N,M)
      implicit real*8 (a-h,o-z)
      save
      REAL*8 A(1),R(1)
      NM=N*M
      DO 10 I=1,NM
10    R(I)=A(I)
      RETURN
      END
